@@ -26,25 +26,41 @@ static void e_webcal_open_cal_http (const gchar * uri, const gchar * old);
 
 static SoupSession * session;
 
-static void e_webcal_load (const gchar * body, const gchar * uri) {
+static gboolean e_webcal_has_kind (icalcomponent * comp, icalcomponent_kind kind)
+{
+  g_return_val_if_fail (comp != NULL, FALSE);
+
+  return (icalcomponent_get_first_component (comp, kind) != NULL);
+}
+
+static void e_webcal_load (const gchar * body, const gchar * uri)
+{
   icalcomponent * comp;
   icalproperty * prop;
   gint i, numprops;
   gchar * tmpname;
   const gchar * name = NULL, * desc = NULL;
+  gboolean has_events, has_tasks;
 
   comp = icalparser_parse_string (body);
   if (comp == NULL) {
-    gchar * message;
+    SoupUri * tmpuri;
+    gchar * message, * tmpname;
+
+    tmpuri = soup_uri_new (uri);
+    tmpname = g_path_get_basename (tmpuri->path);
 
     message = g_strdup_printf (_("There was an error parsing the calendar, "
 				 "\"%s\". Please verify that it is a valid "
 				 "calendar, and try again."),
-			       g_basename (uri));
+			       tmpname);
 
     e_webcal_display_error (_("Error Parsing Calendar"),
 			       message,
 			       NULL);
+
+    g_free (tmpname);
+    soup_uri_free (tmpuri);
     g_free (message);
 
     bonobo_main_quit ();
@@ -72,17 +88,23 @@ static void e_webcal_load (const gchar * body, const gchar * uri) {
     }
   }
 
+  has_tasks  = e_webcal_has_kind (comp, ICAL_VTODO_COMPONENT);
+  has_events = e_webcal_has_kind (comp, ICAL_VEVENT_COMPONENT);
+
   icalcomponent_free (comp);
 
-  e_webcal_query_user (name, desc, uri);
+  e_webcal_query_user (name, desc, uri, has_events, has_tasks);
 
   bonobo_main_quit ();
 }
 
 static void e_webcal_read (SoupMessage * msg, gpointer data) {
+  const SoupUri * tmpuri;
   const gchar * uri = (const gchar *) data;
   const gchar * header;
 
+  tmpuri = soup_message_get_uri (msg);
+
   if (SOUP_STATUS_IS_REDIRECTION (msg->status_code)) {
     header = soup_message_get_header (msg->response_headers, "Location");
     if (header) {
@@ -93,29 +115,36 @@ static void e_webcal_read (SoupMessage * msg, gpointer data) {
 
   if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code)) {
     gchar * errorstring;
+    gchar * errorname;
 
+    errorname = g_path_get_basename (tmpuri->path);
     switch (msg->status_code) {
       /* Handle some common error codes here */
     case SOUP_STATUS_FORBIDDEN:
-      errorstring = g_strdup_printf (_("Access to the calendar at \"%s\" "
-				       "is forbidden."), uri);
+      errorstring = g_strdup_printf (_("Access to the calendar, \"%s\", "
+				       "is forbidden."),
+				     errorname);
       break;
     case SOUP_STATUS_NOT_FOUND:
-      errorstring = g_strdup_printf (_("The calendar at \"%s\" was not "
-				       "found on the server."), uri);
+      errorstring = g_strdup_printf (_("The calendar, \"%s\", was not "
+				       "found on the server."),
+				     errorname);
       break;
     case SOUP_STATUS_INTERNAL_SERVER_ERROR:
       errorstring = g_strdup_printf (_("There was an internal server error "
-				       "while trying to load \"%s\"."), uri);
+				       "while trying to load \"%s\"."),
+				     errorname);
       break;
     default:
       errorstring = g_strdup_printf (_("There was an error loading the "
-				       "calendar at \"%s\"."), uri);
+				       "calendar, \"%s\"."),
+				     errorname);
       break;
     }
     e_webcal_display_error (_("Error Loading Calendar"),
 			    errorstring,
 			    NULL);
+    g_free (errorname);
     g_free (errorstring);
     g_free (data);
     bonobo_main_quit ();
