@@ -115,7 +115,6 @@ void e_webcal_display_error (const gchar * title, const gchar * message,
   dialog = gtk_dialog_new ();
 
   gtk_window_set_title (GTK_WINDOW (dialog), title);
-  gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dialog), TRUE);
   gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent));
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
@@ -226,6 +225,26 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
   gchar * scolor;
   guint32 icolor = 0;
 
+  tmpuri = soup_uri_new (caluri);
+  tmpname = g_path_get_basename (tmpuri->path);
+
+  /* If we are already subscribed, pop up an error dialog */
+  if (!has_events && !has_tasks) {
+    gchar * msg;
+
+    msg = g_strdup_printf (_("No events or tasks were found in the calendar "
+			     "\"%s\"."),
+			   name ? name : tmpname);
+    e_webcal_display_error (_("<b>No Tasks or Events Found</b>"), msg, NULL);
+    g_free (msg);
+
+    g_free (tmpname);
+    soup_uri_free (tmpuri);
+    
+    bonobo_main_quit ();
+    return;
+  }
+
   events_sources = e_source_list_new_for_gconf_default (CALENDAR_SOURCES_KEY);
 
   for (l = e_source_list_peek_groups (events_sources); l != NULL; l = l->next) {
@@ -256,9 +275,6 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
     e_source_list_add_group (tasks_sources, tasks_group, -1);
   }
 
-  tmpuri = soup_uri_new (caluri);
-  tmpname = g_path_get_basename (tmpuri->path);
-
   if (has_events)
     if (e_source_group_peek_source_by_name (events_group,
 					    name ? name : tmpname)) {
@@ -275,7 +291,7 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
   if (!has_events && !has_tasks) {
     gchar * msg;
 
-    msg = g_strdup_printf (_("You are already subscribed to the calendar, "
+    msg = g_strdup_printf (_("You are already subscribed to the calendar "
 			     "\"%s\". Please subscribe to another calendar."),
 			   name ? name : tmpname);
     e_webcal_display_error (_("<b>Already Subscribed</b>"), msg, NULL);
